---
comments: true
icon: material/folder-open
---

# 示例项目

此处会给出一些用 `maliang` 开发的项目的实例。

!!! tip "温馨提示"

    如果你想把你用 tkt 写的项目也加入到这里来，没问题！只要满足以下要求，我就会考虑把你的项目加入到这里！

    - [X] 在 *requirements.txt* 中添加 `maliang`，并注明使用的版本，这样我才能找到你的项目；
    - [X] 在你自己的项目的自述文件中展示一张预览图，这样我才能在这里展示你的项目；

    顺便一提，如果你的项目提供了亮色和暗色双主题预览图，那么这里也会提供双主题的预览图，通过切换网站主题即可查看不同主题的预览图。

|  id   |            项目             |                    项目仓库                    |                                  星标                                   |
| :---: | :-------------------------: | :--------------------------------------------: | :---------------------------------------------------------------------: |
|   1   |  [Login2.0](./users/1.md)   |    <https://github.com/SHTLUOLEI/Login2.0>     |    ![Stars](https://img.shields.io/github/stars/SHTLUOLEI/Login2.0)     |
|   2   | [ArkLauncher](./users/2.md) | <https://github.com/the-OmegaLabs/ArkLauncher> | ![Stars](https://img.shields.io/github/stars/the-OmegaLabs/ArkLauncher) |
